from datetime import datetime, timedelta
from airflow import DAG
from airflow.operators.python_operator import PythonOperator
from airflow.operators.dummy_operator import DummyOperator
import pandas as pd

default_args = {
	'owner': 'airflow',
	'depends_on_past': False,
	'start_date': datetime(2023, 7, 1),
	'email_on_failure': False,
	'email_on_retry': False,
	'retries': 1,
	'retry_delay': timedelta(minutes=5),
}

dag = DAG(
	'my_dag',
	default_args=default_args,
	description='DAG to fetch data and perform some operations',
	schedule_interval=timedelta(days=1),
)

def fetch_sales_data(**kwargs):
	# Example of creating a dummy dataframe for illustration purposes only:
	data = {
    	'date': ['2023-07-21', '2023-07-22'],
    	'sales': [500, 750]
	}
	df = pd.DataFrame(data)
	kwargs['ti'].xcom_push(key='sales_data', value=df)

def process_sales_data(**kwargs):
	df = kwargs['ti'].xcom_pull(key='sales_data')
	average_sales = df['sales'].mean()
	kwargs['ti'].xcom_push(key='average_sales', value=average_sales)

def save_results_to_csv(**kwargs):
	average_sales = kwargs['ti'].xcom_pull(key='average_sales')

	# Create a dataframe to save the results to a CSV file
	results = {
    	'date': [datetime.now().strftime('%Y-%m-%d')],
    	'average_sales': [average_sales]
	}
	df_results = pd.DataFrame(results)
	df_results.to_csv('/path/to/results.csv', index=False)

with dag:
	start = DummyOperator(task_id='start')
    
	fetch_data_task = PythonOperator(
    	task_id='fetch_sales_data',
    	python_callable=fetch_sales_data,
    	provide_context=True,
	)
    
	process_data_task = PythonOperator(
    	task_id='process_sales_data',
    	python_callable=process_sales_data,
    	provide_context=True,
	)

	save_to_csv_task = PythonOperator(
    	task_id='save_results_to_csv',
    	python_callable=save_results_to_csv,
    	provide_context=True,
	)
    
	end = DummyOperator(task_id='end')

	# Set the task dependencies
	start >> fetch_data_task >> process_data_task >> save_to_csv_task >> end
